# Signal processing
This module holds various methods to do signal processing.


## Fast timing discrimination

::: extra.signal.dled

::: extra.signal.cfd

::: extra.signal.EdgeInterpolation
    options:
      members: []
      docstring_section_style: "list"

::: extra.signal.config_ftd_interpolation


## Interpolation

::: extra.signal.sinc_interpolate
